User: sits
Date: 07/09/24 14:25:46
Modified: . CHANGELOG
lib/Codestriker/FileParser ClearCaseSerialDiff.pm
Log:
* Handle ClearCase diffs which contain "Directories are identical"
lines in them. Submitted by Steve Kinsman
<[EMAIL PROTECTED]>.
Index: CHANGELOG
===================================================================
RCS file: /cvsroot/codestriker/codestriker/CHANGELOG,v
retrieving revision 1.215
retrieving revision 1.216
diff -u -r1.215 -r1.216
--- CHANGELOG 25 Aug 2007 09:11:06 -0000 1.215
+++ CHANGELOG 24 Sep 2007 21:25:45 -0000 1.216
@@ -63,6 +63,10 @@
associated bug records. Submitted by Russell Cattelan
<[EMAIL PROTECTED]>.
+* Handle ClearCase diffs which contain "Directories are identical"
+ lines in them. Submitted by Steve Kinsman
+ <[EMAIL PROTECTED]>.
+
Version 1.9.3
* The project list screen now displays for each project, the total
Index: ClearCaseSerialDiff.pm
===================================================================
RCS file:
/cvsroot/codestriker/codestriker/lib/Codestriker/FileParser/ClearCaseSerialDiff.pm,v
retrieving revision 1.4
retrieving revision 1.5
diff -u -r1.4 -r1.5
--- ClearCaseSerialDiff.pm 8 Jun 2004 21:26:39 -0000 1.4
+++ ClearCaseSerialDiff.pm 24 Sep 2007 21:25:45 -0000 1.5
@@ -38,10 +38,12 @@
my $line = <$fh>;
while (defined($line)) {
# Skip any heading or trailing whitespace contained in the review
# text, in addition to the "Files are identical" lines, which happen
# due to the way review texts are generated.
while (defined($line) &&
- ($line =~ /^\s*$/o || $line =~ /^Files are identical$/)) {
+ ($line =~ /^\s*$/o ||
+ $line =~ /^Files are identical$/o ||
+ $line =~ /^Directories are identical$/o)) {
$line = <$fh>;
}
return @result unless defined $line;
@@ -62,7 +64,7 @@
# This is very simple for now, but will need to be more
# sophisticated later.
if (defined $repository_root &&
- $filename =~ /^$repository_root[\/\\](.*)$/) {
+ $filename =~ /^$repository_root[\/\\](.*)$/o) {
$filename = $1;
$repmatch = 1;
} else {
@@ -99,7 +101,7 @@
# This is very simple for now, but will need to be more
# sophisticated later.
if (defined $repository_root &&
- $filename =~ /^$repository_root[\/\\](.*)$/) {
+ $filename =~ /^$repository_root[\/\\](.*)$/o) {
$filename = $1;
}
@@ -119,7 +121,8 @@
$line = <$fh>;
while (defined $line &&
$line !~
/^\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*\*$/o) {
- if ($line !~ /^Files are identical$/o) {
+ if ($line !~ /^Files are identical$/o &&
+ $line !~ /^Directories are identical$/o) {
$text .= "+$line";
}
$line = <$fh>;
-------------------------------------------------------------------------
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse0120000070mrt/direct/01/
@@ -38,10 +38,12 @@
while (defined($line)) {
# Skip any heading or trailing whitespace contained in the review
- # text, in addition to the "Files are identical" lines, which happen
- # due to the way review texts are generated.
+ # text, in addition to the "Files/Directories are identical" lines,
+ # which happen due to the way review texts are generated.
while (defined($line) &&
_______________________________________________
Codestriker-commits mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/codestriker-commits